@@ -52,9 +52,14 @@ image_opts = {
 
 http_opts = {
     'method': str(),
-    'timeout': number(),
+    'client_timeout': number(),
     'ssl_no_cert_checks': bool(),
+    'ssl_ca_certs': str(),
+    'headers': {
+        anything(): str()
+    },
 }
+
 mapserver_opts = {
     'binary': str(),
     'working_dir': str(),
@@ -76,6 +81,15 @@ source_commons = combined(
     }
 )
 
+cache_types = {
+    'file': {
+        'directory_layout': str()
+    },
+    'mbtiles': {
+        'filename': str()
+    }
+}
+
 mapproxy_yaml_spec = {
     'globals': {
         'image': {
@@ -89,9 +103,7 @@ mapproxy_yaml_spec = {
             },
             'font_dir': str(),
         },
-        'http': {
-            'timeout': number(),
-        },
+        'http': http_opts,
         'cache': {
             'base_dir': str(),
             'lock_dir': str(),
@@ -108,6 +120,9 @@ mapproxy_yaml_spec = {
           'axis_order_en': [str()],
           'proj_data_dir': str(),
         },
+        'tiles': {
+            'expires_hours': number(),
+        },
         'mapserver': mapserver_opts,
     },
     'grids': {
@@ -152,7 +167,8 @@ mapproxy_yaml_spec = {
                 'font_size': number(),
                 'opacity': number(),
                 'spacing': str(),
-            }
+            },
+            'cache': type_spec('type', cache_types)
         }
     },
     'services': {
@@ -238,6 +254,7 @@ mapproxy_yaml_spec = {
                 required('mapfile'): str(),
                 'transparent': bool(),
                 'image': image_opts,
+                'layers': one_off(str(), [str()]),
             }),
             'debug': {
             },
