@@ -1,18 +1,17 @@
 # This file is part of the MapProxy project.
 # Copyright (C) 2010 Omniscale <http://omniscale.de>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# 
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
+#    http://www.apache.org/licenses/LICENSE-2.0
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """
 Demo service handler
@@ -22,16 +21,14 @@ import mimetypes
 from urllib2 import urlopen
 from collections import defaultdict
 
+from mapproxy.exception import RequestError
 from mapproxy.service.base import Server
 from mapproxy.response import Response
-from mapproxy.config import base_config
 
 from mapproxy.template import template_loader, bunch
 env = {'bunch': bunch}
 get_template = template_loader(__file__, 'templates', namespace=env)
 
-import logging
-log = logging.getLogger(__name__)
 
 class DemoServer(Server):
     names = ('demo',)
@@ -41,13 +38,13 @@ class DemoServer(Server):
         self.layers = layers
         self.tile_layers = tile_layers or {}
         self.md = md
-        self.image_formats = image_formats or base_config().wms.image_formats
+        self.image_formats = image_formats
         filter_image_format = []
         for format in self.image_formats:
             if 'image/jpeg' == format or 'image/png' == format:
                 filter_image_format.append(format)
         self.image_formats = filter_image_format
-        self.srs = srs or base_config().wms.srs
+        self.srs = srs
 
     def handle(self, req):
         if req.path.startswith('/demo/static/'):
@@ -61,8 +58,12 @@ class DemoServer(Server):
             return Response(open(static_file, 'rb'), content_type=type)
         
         # we don't authorize the static files (css, js)
-        # since they are not confidetial
-        if not self.authorized_demo(req.environ):
+        # since they are not confidential
+        try:
+            authorized = self.authorized_demo(req.environ)
+        except RequestError, ex:
+            return ex.render()
+        if not authorized:
             return Response('forbidden', content_type='text/plain', status=403)
         
         if 'wms_layer' in req.args:
@@ -142,7 +143,9 @@ class DemoServer(Server):
 
     def authorized_demo(self, environ):
         if 'mapproxy.authorize' in environ:
-            result = environ['mapproxy.authorize']('demo', [])
+            result = environ['mapproxy.authorize']('demo', [], environ=environ)
+            if result['authorized'] == 'unauthenticated':
+                raise RequestError('unauthorized', status=401)
             if result['authorized'] == 'full':
                 return True
             return False
