@@ -1,3 +1,18 @@
+# This file is part of the MapProxy project.
+# Copyright (C) 2010 Omniscale <http://omniscale.de>
+# 
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
+#    http://www.apache.org/licenses/LICENSE-2.0
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import re
 
 from mapproxy.response import Response
@@ -5,7 +20,6 @@ from mapproxy.exception import RequestError, PlainExceptionHandler
 from mapproxy.service.base import Server
 from mapproxy.request.tile import TileRequest
 from mapproxy.srs import SRS
-from mapproxy.config import base_config
 
 class KMLRequest(TileRequest):
     """
@@ -40,12 +54,11 @@ class KMLServer(Server):
     request_parser = staticmethod(kml_request)
     request_methods = ('map', 'kml')
 
-    def __init__(self, layers, md):
+    def __init__(self, layers, md, max_tile_age=None):
         Server.__init__(self)
         self.layers = layers
         self.md = md
-        
-        self.max_age = base_config().tiles.expires_hours * 60 * 60
+        self.max_tile_age = max_tile_age
     
     def map(self, map_request):
         """
@@ -57,13 +70,15 @@ class KMLServer(Server):
         resp = Response(tile.as_buffer(),
                         content_type='image/' + map_request.format)
         resp.cache_headers(tile.timestamp, etag_data=(tile.timestamp, tile.size),
-                           max_age=base_config().tiles.expires_hours * 60 * 60)
+                           max_age=self.max_tile_age)
         resp.make_conditional(map_request.http)
         return resp
     
     def authorize_tile_layer(self, layer_name, env):
         if 'mapproxy.authorize' in env:
-            result = env['mapproxy.authorize']('kml', [layer_name])
+            result = env['mapproxy.authorize']('kml', [layer_name], environ=env)
+            if result['authorized'] == 'unauthenticated':
+                raise RequestError('unauthorized', status=401)
             if result['authorized'] == 'full':
                 return
             if result['authorized'] == 'partial':
@@ -106,7 +121,7 @@ class KMLServer(Server):
             url=url, name=map_request.layer, format=layer.format, name_path=layer.md['name_path'],
             initial_level=initial_level, tile_size=tile_size)
         resp = Response(result, content_type='application/vnd.google-earth.kml+xml')
-        resp.cache_headers(etag_data=(result,), max_age=self.max_age)
+        resp.cache_headers(etag_data=(result,), max_age=self.max_tile_age)
         resp.make_conditional(map_request.http)
         return resp
 
