@@ -2,18 +2,17 @@
 # This file is part of the MapProxy project.
 # Copyright (C) 2010 Omniscale <http://omniscale.de>
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
+#    http://www.apache.org/licenses/LICENSE-2.0
 # 
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 
 """
 Spatial reference systems and transformation of coordinates.
@@ -27,7 +26,8 @@ from mapproxy.proj import Proj, transform, set_datapath, ProjInitError
 from mapproxy.config import base_config
 
 import logging
-log = logging.getLogger(__name__)
+log_system = logging.getLogger('mapproxy.system')
+log_proj = logging.getLogger('mapproxy.proj')
 
 def get_epsg_num(epsg_code):
     """
@@ -67,7 +67,7 @@ def _init_proj():
     global _proj_initalized
     if not _proj_initalized and 'proj_data_dir' in base_config().srs:
         proj_data_dir = base_config().srs['proj_data_dir']
-        log.info('loading proj data from %s', proj_data_dir)
+        log_system.info('loading proj data from %s', proj_data_dir)
         set_datapath(proj_data_dir)
         _proj_initalized = True
 
@@ -199,7 +199,7 @@ class _SRS(object):
         transf_pts = self.transform_to(other_srs, points)
         result = calculate_bbox(transf_pts)
         
-        log.debug('transformed from %r to %r (%s -> %s)' % 
+        log_proj.debug('transformed from %r to %r (%s -> %s)' % 
                   (self, other_srs, bbox, result))
         
         return result
